# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'PolicyIEMap',
    'PolicyPolicyTag',
    'PolicyResourceTag',
]

@pulumi.output_type
class PolicyIEMap(dict):
    """
    An FMS includeMap or excludeMap.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "aCCOUNT":
            suggest = "a_ccount"
        elif key == "oRGUNIT":
            suggest = "o_rgunit"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicyIEMap. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicyIEMap.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicyIEMap.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 a_ccount: Optional[Sequence[str]] = None,
                 o_rgunit: Optional[Sequence[str]] = None):
        """
        An FMS includeMap or excludeMap.
        """
        if a_ccount is not None:
            pulumi.set(__self__, "a_ccount", a_ccount)
        if o_rgunit is not None:
            pulumi.set(__self__, "o_rgunit", o_rgunit)

    @property
    @pulumi.getter(name="aCCOUNT")
    def a_ccount(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "a_ccount")

    @property
    @pulumi.getter(name="oRGUNIT")
    def o_rgunit(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "o_rgunit")


@pulumi.output_type
class PolicyPolicyTag(dict):
    """
    A policy tag.
    """
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        A policy tag.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class PolicyResourceTag(dict):
    """
    A resource tag.
    """
    def __init__(__self__, *,
                 key: str,
                 value: Optional[str] = None):
        """
        A resource tag.
        """
        pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        return pulumi.get(self, "value")


