# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'FlowTemplateDefinitionDocument',
]

@pulumi.output_type
class FlowTemplateDefinitionDocument(dict):
    def __init__(__self__, *,
                 language: str,
                 text: str):
        pulumi.set(__self__, "language", language)
        pulumi.set(__self__, "text", text)

    @property
    @pulumi.getter
    def language(self) -> str:
        return pulumi.get(self, "language")

    @property
    @pulumi.getter
    def text(self) -> str:
        return pulumi.get(self, "text")


