# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'FHIRDatastoreDatastoreStatus',
    'FHIRDatastoreDatastoreTypeVersion',
    'FHIRDatastoreKmsEncryptionConfigCmkType',
    'FHIRDatastorePreloadDataConfigPreloadDataType',
]


class FHIRDatastoreDatastoreStatus(str, Enum):
    """
    The status of the Data Store. Possible statuses are 'CREATING', 'ACTIVE', 'DELETING', or 'DELETED'.
    """
    CREATING = "CREATING"
    ACTIVE = "ACTIVE"
    DELETING = "DELETING"
    DELETED = "DELETED"


class FHIRDatastoreDatastoreTypeVersion(str, Enum):
    """
    The FHIR version. Only R4 version data is supported.
    """
    R4 = "R4"


class FHIRDatastoreKmsEncryptionConfigCmkType(str, Enum):
    """
    The type of customer-managed-key (CMK) used for encryption. The two types of supported CMKs are customer owned CMKs and AWS owned CMKs.
    """
    CUSTOMER_MANAGED_KMS_KEY = "CUSTOMER_MANAGED_KMS_KEY"
    AWS_OWNED_KMS_KEY = "AWS_OWNED_KMS_KEY"


class FHIRDatastorePreloadDataConfigPreloadDataType(str, Enum):
    """
    The type of preloaded data. Only Synthea preloaded data is supported.
    """
    SYNTHEA = "SYNTHEA"
