# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'GeofenceCollectionPricingPlan',
    'MapPricingPlan',
    'PlaceIndexIntendedUse',
    'PlaceIndexPricingPlan',
    'RouteCalculatorPricingPlan',
    'TrackerPricingPlan',
]


class GeofenceCollectionPricingPlan(str, Enum):
    REQUEST_BASED_USAGE = "RequestBasedUsage"
    MOBILE_ASSET_TRACKING = "MobileAssetTracking"
    MOBILE_ASSET_MANAGEMENT = "MobileAssetManagement"


class MapPricingPlan(str, Enum):
    REQUEST_BASED_USAGE = "RequestBasedUsage"
    MOBILE_ASSET_TRACKING = "MobileAssetTracking"
    MOBILE_ASSET_MANAGEMENT = "MobileAssetManagement"


class PlaceIndexIntendedUse(str, Enum):
    SINGLE_USE = "SingleUse"
    STORAGE = "Storage"


class PlaceIndexPricingPlan(str, Enum):
    REQUEST_BASED_USAGE = "RequestBasedUsage"
    MOBILE_ASSET_TRACKING = "MobileAssetTracking"
    MOBILE_ASSET_MANAGEMENT = "MobileAssetManagement"


class RouteCalculatorPricingPlan(str, Enum):
    REQUEST_BASED_USAGE = "RequestBasedUsage"
    MOBILE_ASSET_MANAGEMENT = "MobileAssetManagement"


class TrackerPricingPlan(str, Enum):
    REQUEST_BASED_USAGE = "RequestBasedUsage"
    MOBILE_ASSET_TRACKING = "MobileAssetTracking"
    MOBILE_ASSET_MANAGEMENT = "MobileAssetManagement"
