# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'AccessPointNetworkOrigin',
    'StorageLensS3BucketDestinationFormat',
    'StorageLensS3BucketDestinationOutputSchemaVersion',
]


class AccessPointNetworkOrigin(str, Enum):
    """
    Indicates whether this Access Point allows access from the public Internet. If VpcConfiguration is specified for this Access Point, then NetworkOrigin is VPC, and the Access Point doesn't allow access from the public Internet. Otherwise, NetworkOrigin is Internet, and the Access Point allows access from the public Internet, subject to the Access Point and bucket access policies.
    """
    INTERNET = "Internet"
    VPC = "VPC"


class StorageLensS3BucketDestinationFormat(str, Enum):
    """
    Specifies the file format to use when exporting Amazon S3 Storage Lens metrics export.
    """
    CSV = "CSV"
    PARQUET = "Parquet"


class StorageLensS3BucketDestinationOutputSchemaVersion(str, Enum):
    """
    The version of the output schema to use when exporting Amazon S3 Storage Lens metrics.
    """
    V1 = "V_1"
