# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'DBProxyAuthFormatAuthScheme',
    'DBProxyAuthFormatIAMAuth',
    'DBProxyEndpointTargetRole',
    'DBProxyEngineFamily',
    'DBProxyTargetGroupTargetGroupName',
    'GlobalClusterEngine',
]


class DBProxyAuthFormatAuthScheme(str, Enum):
    """
    The type of authentication that the proxy uses for connections from the proxy to the underlying database. 
    """
    SECRETS = "SECRETS"


class DBProxyAuthFormatIAMAuth(str, Enum):
    """
    Whether to require or disallow AWS Identity and Access Management (IAM) authentication for connections to the proxy. 
    """
    DISABLED = "DISABLED"
    REQUIRED = "REQUIRED"


class DBProxyEndpointTargetRole(str, Enum):
    """
    A value that indicates whether the DB proxy endpoint can be used for read/write or read-only operations.
    """
    READ_WRITE = "READ_WRITE"
    READ_ONLY = "READ_ONLY"


class DBProxyEngineFamily(str, Enum):
    """
    The kinds of databases that the proxy can connect to.
    """
    MYSQL = "MYSQL"
    POSTGRESQL = "POSTGRESQL"


class DBProxyTargetGroupTargetGroupName(str, Enum):
    """
    The identifier for the DBProxyTargetGroup
    """
    DEFAULT = "default"


class GlobalClusterEngine(str, Enum):
    """
    The name of the database engine to be used for this DB cluster. Valid Values: aurora (for MySQL 5.6-compatible Aurora), aurora-mysql (for MySQL 5.7-compatible Aurora).
    If you specify the SourceDBClusterIdentifier property, don't specify this property. The value is inherited from the cluster.
    """
    AURORA = "aurora"
    AURORA_MYSQL = "aurora-mysql"
    AURORA_POSTGRESQL = "aurora-postgresql"
