# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'FindingsFilterFindingFilterAction',
    'SessionFindingPublishingFrequency',
    'SessionStatus',
]


class FindingsFilterFindingFilterAction(str, Enum):
    ARCHIVE = "ARCHIVE"
    NOOP = "NOOP"


class SessionFindingPublishingFrequency(str, Enum):
    """
    A enumeration value that specifies how frequently finding updates are published.
    """
    FIFTEEN_MINUTES = "FIFTEEN_MINUTES"
    ONE_HOUR = "ONE_HOUR"
    SIX_HOURS = "SIX_HOURS"


class SessionStatus(str, Enum):
    """
    A enumeration value that specifies the status of the Macie Session.
    """
    ENABLED = "ENABLED"
    PAUSED = "PAUSED"
