# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'DetectorModelEvaluationMethod',
]


class DetectorModelEvaluationMethod(str, Enum):
    """
    Information about the order in which events are evaluated and how actions are executed.
    """
    BATCH = "BATCH"
    SERIAL = "SERIAL"
