# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ExperimentTemplateExperimentTemplateActionMapArgs',
    'ExperimentTemplateExperimentTemplateStopConditionArgs',
    'ExperimentTemplateExperimentTemplateTargetMapArgs',
]

@pulumi.input_type
class ExperimentTemplateExperimentTemplateActionMapArgs:
    def __init__(__self__):
        """
        The actions for the experiment.
        """
        pass


@pulumi.input_type
class ExperimentTemplateExperimentTemplateStopConditionArgs:
    def __init__(__self__, *,
                 source: pulumi.Input[str],
                 value: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "source", source)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def source(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: pulumi.Input[str]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class ExperimentTemplateExperimentTemplateTargetMapArgs:
    def __init__(__self__):
        """
        The targets for the experiment.
        """
        pass


