# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ConnectionAliasConnectionAliasAssociationAssociationStatus',
    'ConnectionAliasConnectionAliasState',
]


class ConnectionAliasConnectionAliasAssociationAssociationStatus(str, Enum):
    NOT_ASSOCIATED = "NOT_ASSOCIATED"
    PENDING_ASSOCIATION = "PENDING_ASSOCIATION"
    ASSOCIATED_WITH_OWNER_ACCOUNT = "ASSOCIATED_WITH_OWNER_ACCOUNT"
    ASSOCIATED_WITH_SHARED_ACCOUNT = "ASSOCIATED_WITH_SHARED_ACCOUNT"
    PENDING_DISASSOCIATION = "PENDING_DISASSOCIATION"


class ConnectionAliasConnectionAliasState(str, Enum):
    CREATING = "CREATING"
    CREATED = "CREATED"
    DELETING = "DELETING"
