# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'KeySigningKeyStatus',
]


class KeySigningKeyStatus(str, Enum):
    """
    A string specifying the initial status of the key signing key (KSK). You can set the value to ACTIVE or INACTIVE.
    """
    ACTIVE = "ACTIVE"
    INACTIVE = "INACTIVE"
