# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'GroupResourceQueryType',
]


class GroupResourceQueryType(str, Enum):
    TAG_FILTERS10 = "TAG_FILTERS_1_0"
    CLOUDFORMATION_STACK10 = "CLOUDFORMATION_STACK_1_0"
