# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'SigningProfilePlatformId',
    'SigningProfileSignatureValidityPeriodType',
]


class SigningProfilePlatformId(str, Enum):
    AWS_LAMBDA_SHA384_ECDSA = "AWSLambda-SHA384-ECDSA"


class SigningProfileSignatureValidityPeriodType(str, Enum):
    DAYS = "DAYS"
    MONTHS = "MONTHS"
    YEARS = "YEARS"
