# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'StateMachineLoggingConfigurationLevel',
    'StateMachineStateMachineType',
]


class StateMachineLoggingConfigurationLevel(str, Enum):
    ALL = "ALL"
    ERROR = "ERROR"
    FATAL = "FATAL"
    OFF = "OFF"


class StateMachineStateMachineType(str, Enum):
    STANDARD = "STANDARD"
    EXPRESS = "EXPRESS"
