# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'TableClusteringKeyColumnOrderBy',
    'TableEncryptionType',
    'TableMode',
]


class TableClusteringKeyColumnOrderBy(str, Enum):
    ASC = "ASC"
    DESC = "DESC"


class TableEncryptionType(str, Enum):
    """
    Server-side encryption type
    """
    AWS_OWNED_KMS_KEY = "AWS_OWNED_KMS_KEY"
    CUSTOMER_MANAGED_KMS_KEY = "CUSTOMER_MANAGED_KMS_KEY"


class TableMode(str, Enum):
    """
    Capacity mode for the specified table
    """
    PROVISIONED = "PROVISIONED"
    ON_DEMAND = "ON_DEMAND"
