# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'TrailEventSelectorReadWriteType',
]


class TrailEventSelectorReadWriteType(str, Enum):
    """
    Specify if you want your trail to log read-only events, write-only events, or all. For example, the EC2 GetConsoleOutput is a read-only API operation and RunInstances is a write-only API operation.
    """
    ALL = "All"
    READ_ONLY = "ReadOnly"
    WRITE_ONLY = "WriteOnly"
