# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'StreamStreamEncryptionEncryptionType',
]


class StreamStreamEncryptionEncryptionType(str, Enum):
    """
    The encryption type to use. The only valid value is KMS. 
    """
    KMS = "KMS"
