# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'StudioAuthMode',
    'StudioSessionMappingIdentityType',
]


class StudioAuthMode(str, Enum):
    """
    Specifies whether the Studio authenticates users using single sign-on (SSO) or IAM. Amazon EMR Studio currently only supports SSO authentication.
    """
    SSO = "SSO"
    IAM = "IAM"


class StudioSessionMappingIdentityType(str, Enum):
    """
    Specifies whether the identity to map to the Studio is a user or a group.
    """
    USER = "USER"
    GROUP = "GROUP"
