# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from ._enums import *

__all__ = [
    'ApplicationTagsArgs',
    'AttributeGroupTagsArgs',
]

@pulumi.input_type
class ApplicationTagsArgs:
    def __init__(__self__):
        pass


@pulumi.input_type
class AttributeGroupTagsArgs:
    def __init__(__self__):
        pass


