# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ResourceAssociationResourceType',
]


class ResourceAssociationResourceType(str, Enum):
    """
    The type of the CFN Resource for now it's enum CFN_STACK.
    """
    CFN_STACK = "CFN_STACK"
