# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'DetectorDetectorVersionStatus',
    'DetectorEventVariableDataSource',
    'DetectorEventVariableDataType',
    'DetectorEventVariableVariableType',
    'DetectorRuleExecutionMode',
    'DetectorRuleLanguage',
    'EventTypeEventVariableDataSource',
    'EventTypeEventVariableDataType',
    'EventTypeEventVariableVariableType',
    'VariableDataSource',
    'VariableDataType',
    'VariableVariableType',
]


class DetectorDetectorVersionStatus(str, Enum):
    """
    The desired detector version status for the detector
    """
    DRAFT = "DRAFT"
    ACTIVE = "ACTIVE"


class DetectorEventVariableDataSource(str, Enum):
    EVENT = "EVENT"


class DetectorEventVariableDataType(str, Enum):
    STRING = "STRING"
    INTEGER = "INTEGER"
    FLOAT = "FLOAT"
    BOOLEAN = "BOOLEAN"


class DetectorEventVariableVariableType(str, Enum):
    AUTH_CODE = "AUTH_CODE"
    AVS = "AVS"
    BILLING_ADDRESS_L1 = "BILLING_ADDRESS_L1"
    BILLING_ADDRESS_L2 = "BILLING_ADDRESS_L2"
    BILLING_CITY = "BILLING_CITY"
    BILLING_COUNTRY = "BILLING_COUNTRY"
    BILLING_NAME = "BILLING_NAME"
    BILLING_PHONE = "BILLING_PHONE"
    BILLING_STATE = "BILLING_STATE"
    BILLING_ZIP = "BILLING_ZIP"
    CARD_BIN = "CARD_BIN"
    CATEGORICAL = "CATEGORICAL"
    CURRENCY_CODE = "CURRENCY_CODE"
    EMAIL_ADDRESS = "EMAIL_ADDRESS"
    FINGERPRINT = "FINGERPRINT"
    FRAUD_LABEL = "FRAUD_LABEL"
    FREE_FORM_TEXT = "FREE_FORM_TEXT"
    IP_ADDRESS = "IP_ADDRESS"
    NUMERIC = "NUMERIC"
    ORDER_ID = "ORDER_ID"
    PAYMENT_TYPE = "PAYMENT_TYPE"
    PHONE_NUMBER = "PHONE_NUMBER"
    PRICE = "PRICE"
    PRODUCT_CATEGORY = "PRODUCT_CATEGORY"
    SHIPPING_ADDRESS_L1 = "SHIPPING_ADDRESS_L1"
    SHIPPING_ADDRESS_L2 = "SHIPPING_ADDRESS_L2"
    SHIPPING_CITY = "SHIPPING_CITY"
    SHIPPING_COUNTRY = "SHIPPING_COUNTRY"
    SHIPPING_NAME = "SHIPPING_NAME"
    SHIPPING_PHONE = "SHIPPING_PHONE"
    SHIPPING_STATE = "SHIPPING_STATE"
    SHIPPING_ZIP = "SHIPPING_ZIP"
    USERAGENT = "USERAGENT"


class DetectorRuleExecutionMode(str, Enum):
    FIRST_MATCHED = "FIRST_MATCHED"
    ALL_MATCHED = "ALL_MATCHED"


class DetectorRuleLanguage(str, Enum):
    DETECTORPL = "DETECTORPL"


class EventTypeEventVariableDataSource(str, Enum):
    EVENT = "EVENT"


class EventTypeEventVariableDataType(str, Enum):
    STRING = "STRING"
    INTEGER = "INTEGER"
    FLOAT = "FLOAT"
    BOOLEAN = "BOOLEAN"


class EventTypeEventVariableVariableType(str, Enum):
    AUTH_CODE = "AUTH_CODE"
    AVS = "AVS"
    BILLING_ADDRESS_L1 = "BILLING_ADDRESS_L1"
    BILLING_ADDRESS_L2 = "BILLING_ADDRESS_L2"
    BILLING_CITY = "BILLING_CITY"
    BILLING_COUNTRY = "BILLING_COUNTRY"
    BILLING_NAME = "BILLING_NAME"
    BILLING_PHONE = "BILLING_PHONE"
    BILLING_STATE = "BILLING_STATE"
    BILLING_ZIP = "BILLING_ZIP"
    CARD_BIN = "CARD_BIN"
    CATEGORICAL = "CATEGORICAL"
    CURRENCY_CODE = "CURRENCY_CODE"
    EMAIL_ADDRESS = "EMAIL_ADDRESS"
    FINGERPRINT = "FINGERPRINT"
    FRAUD_LABEL = "FRAUD_LABEL"
    FREE_FORM_TEXT = "FREE_FORM_TEXT"
    IP_ADDRESS = "IP_ADDRESS"
    NUMERIC = "NUMERIC"
    ORDER_ID = "ORDER_ID"
    PAYMENT_TYPE = "PAYMENT_TYPE"
    PHONE_NUMBER = "PHONE_NUMBER"
    PRICE = "PRICE"
    PRODUCT_CATEGORY = "PRODUCT_CATEGORY"
    SHIPPING_ADDRESS_L1 = "SHIPPING_ADDRESS_L1"
    SHIPPING_ADDRESS_L2 = "SHIPPING_ADDRESS_L2"
    SHIPPING_CITY = "SHIPPING_CITY"
    SHIPPING_COUNTRY = "SHIPPING_COUNTRY"
    SHIPPING_NAME = "SHIPPING_NAME"
    SHIPPING_PHONE = "SHIPPING_PHONE"
    SHIPPING_STATE = "SHIPPING_STATE"
    SHIPPING_ZIP = "SHIPPING_ZIP"
    USERAGENT = "USERAGENT"


class VariableDataSource(str, Enum):
    """
    The source of the data.
    """
    EVENT = "EVENT"
    EXTERNAL_MODEL_SCORE = "EXTERNAL_MODEL_SCORE"


class VariableDataType(str, Enum):
    """
    The data type.
    """
    STRING = "STRING"
    INTEGER = "INTEGER"
    FLOAT = "FLOAT"
    BOOLEAN = "BOOLEAN"


class VariableVariableType(str, Enum):
    """
    The variable type. For more information see https://docs.aws.amazon.com/frauddetector/latest/ug/create-a-variable.html#variable-types
    """
    AUTH_CODE = "AUTH_CODE"
    AVS = "AVS"
    BILLING_ADDRESS_L1 = "BILLING_ADDRESS_L1"
    BILLING_ADDRESS_L2 = "BILLING_ADDRESS_L2"
    BILLING_CITY = "BILLING_CITY"
    BILLING_COUNTRY = "BILLING_COUNTRY"
    BILLING_NAME = "BILLING_NAME"
    BILLING_PHONE = "BILLING_PHONE"
    BILLING_STATE = "BILLING_STATE"
    BILLING_ZIP = "BILLING_ZIP"
    CARD_BIN = "CARD_BIN"
    CATEGORICAL = "CATEGORICAL"
    CURRENCY_CODE = "CURRENCY_CODE"
    EMAIL_ADDRESS = "EMAIL_ADDRESS"
    FINGERPRINT = "FINGERPRINT"
    FRAUD_LABEL = "FRAUD_LABEL"
    FREE_FORM_TEXT = "FREE_FORM_TEXT"
    IP_ADDRESS = "IP_ADDRESS"
    NUMERIC = "NUMERIC"
    ORDER_ID = "ORDER_ID"
    PAYMENT_TYPE = "PAYMENT_TYPE"
    PHONE_NUMBER = "PHONE_NUMBER"
    PRICE = "PRICE"
    PRODUCT_CATEGORY = "PRODUCT_CATEGORY"
    SHIPPING_ADDRESS_L1 = "SHIPPING_ADDRESS_L1"
    SHIPPING_ADDRESS_L2 = "SHIPPING_ADDRESS_L2"
    SHIPPING_CITY = "SHIPPING_CITY"
    SHIPPING_COUNTRY = "SHIPPING_COUNTRY"
    SHIPPING_NAME = "SHIPPING_NAME"
    SHIPPING_PHONE = "SHIPPING_PHONE"
    SHIPPING_STATE = "SHIPPING_STATE"
    SHIPPING_ZIP = "SHIPPING_ZIP"
    USERAGENT = "USERAGENT"
