# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ResponsePlanSsmAutomationTargetAccount',
]


class ResponsePlanSsmAutomationTargetAccount(str, Enum):
    """
    The account type to use when starting the SSM automation document.
    """
    IMPACTED_ACCOUNT = "IMPACTED_ACCOUNT"
    RESPONSE_PLAN_OWNER_ACCOUNT = "RESPONSE_PLAN_OWNER_ACCOUNT"
