# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'DetectorCFNDataSourceConfigurations',
    'DetectorCFNS3LogsConfiguration',
    'FilterCondition',
    'FilterFindingCriteria',
]

@pulumi.output_type
class DetectorCFNDataSourceConfigurations(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "s3Logs":
            suggest = "s3_logs"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DetectorCFNDataSourceConfigurations. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DetectorCFNDataSourceConfigurations.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DetectorCFNDataSourceConfigurations.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 s3_logs: Optional['outputs.DetectorCFNS3LogsConfiguration'] = None):
        if s3_logs is not None:
            pulumi.set(__self__, "s3_logs", s3_logs)

    @property
    @pulumi.getter(name="s3Logs")
    def s3_logs(self) -> Optional['outputs.DetectorCFNS3LogsConfiguration']:
        return pulumi.get(self, "s3_logs")


@pulumi.output_type
class DetectorCFNS3LogsConfiguration(dict):
    def __init__(__self__, *,
                 enable: Optional[bool] = None):
        if enable is not None:
            pulumi.set(__self__, "enable", enable)

    @property
    @pulumi.getter
    def enable(self) -> Optional[bool]:
        return pulumi.get(self, "enable")


@pulumi.output_type
class FilterCondition(dict):
    def __init__(__self__, *,
                 eq: Optional[Sequence[str]] = None,
                 gte: Optional[int] = None,
                 lt: Optional[int] = None,
                 lte: Optional[int] = None,
                 neq: Optional[Sequence[str]] = None):
        if eq is not None:
            pulumi.set(__self__, "eq", eq)
        if gte is not None:
            pulumi.set(__self__, "gte", gte)
        if lt is not None:
            pulumi.set(__self__, "lt", lt)
        if lte is not None:
            pulumi.set(__self__, "lte", lte)
        if neq is not None:
            pulumi.set(__self__, "neq", neq)

    @property
    @pulumi.getter
    def eq(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "eq")

    @property
    @pulumi.getter
    def gte(self) -> Optional[int]:
        return pulumi.get(self, "gte")

    @property
    @pulumi.getter
    def lt(self) -> Optional[int]:
        return pulumi.get(self, "lt")

    @property
    @pulumi.getter
    def lte(self) -> Optional[int]:
        return pulumi.get(self, "lte")

    @property
    @pulumi.getter
    def neq(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "neq")


@pulumi.output_type
class FilterFindingCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "itemType":
            suggest = "item_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FilterFindingCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FilterFindingCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FilterFindingCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 criterion: Optional[Any] = None,
                 item_type: Optional['outputs.FilterCondition'] = None):
        if criterion is not None:
            pulumi.set(__self__, "criterion", criterion)
        if item_type is not None:
            pulumi.set(__self__, "item_type", item_type)

    @property
    @pulumi.getter
    def criterion(self) -> Optional[Any]:
        return pulumi.get(self, "criterion")

    @property
    @pulumi.getter(name="itemType")
    def item_type(self) -> Optional['outputs.FilterCondition']:
        return pulumi.get(self, "item_type")


