# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ProfilingGroupComputePlatform',
]


class ProfilingGroupComputePlatform(str, Enum):
    """
    The compute platform of the profiling group.
    """
    DEFAULT = "Default"
    AWS_LAMBDA = "AWSLambda"
