# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ResourceCollectionResourceCollectionType',
]


class ResourceCollectionResourceCollectionType(str, Enum):
    """
    The type of ResourceCollection
    """
    AWS_CLOUD_FORMATION = "AWS_CLOUD_FORMATION"
