# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['CustomResourceArgs', 'CustomResource']

@pulumi.input_type
class CustomResourceArgs:
    def __init__(__self__, *,
                 service_token: pulumi.Input[str]):
        """
        The set of arguments for constructing a CustomResource resource.
        """
        pulumi.set(__self__, "service_token", service_token)

    @property
    @pulumi.getter(name="serviceToken")
    def service_token(self) -> pulumi.Input[str]:
        return pulumi.get(self, "service_token")

    @service_token.setter
    def service_token(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_token", value)


warnings.warn("""CustomResource is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)


class CustomResource(pulumi.CustomResource):
    warnings.warn("""CustomResource is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 service_token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Resource Type definition for AWS::CloudFormation::CustomResource

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomResourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource Type definition for AWS::CloudFormation::CustomResource

        :param str resource_name: The name of the resource.
        :param CustomResourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomResourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 service_token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""CustomResource is deprecated: CustomResource is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""")
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomResourceArgs.__new__(CustomResourceArgs)

            if service_token is None and not opts.urn:
                raise TypeError("Missing required property 'service_token'")
            __props__.__dict__["service_token"] = service_token
        super(CustomResource, __self__).__init__(
            'aws-native:cloudformation:CustomResource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'CustomResource':
        """
        Get an existing CustomResource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = CustomResourceArgs.__new__(CustomResourceArgs)

        __props__.__dict__["service_token"] = None
        return CustomResource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="serviceToken")
    def service_token(self) -> pulumi.Output[str]:
        return pulumi.get(self, "service_token")

