# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'VirtualClusterContainerInfo',
    'VirtualClusterContainerProvider',
    'VirtualClusterEksInfo',
    'VirtualClusterTag',
]

@pulumi.output_type
class VirtualClusterContainerInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "eksInfo":
            suggest = "eks_info"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VirtualClusterContainerInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VirtualClusterContainerInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VirtualClusterContainerInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 eks_info: 'outputs.VirtualClusterEksInfo'):
        pulumi.set(__self__, "eks_info", eks_info)

    @property
    @pulumi.getter(name="eksInfo")
    def eks_info(self) -> 'outputs.VirtualClusterEksInfo':
        return pulumi.get(self, "eks_info")


@pulumi.output_type
class VirtualClusterContainerProvider(dict):
    def __init__(__self__, *,
                 id: str,
                 info: 'outputs.VirtualClusterContainerInfo',
                 type: str):
        """
        :param str id: The ID of the container cluster
        :param str type: The type of the container provider
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "info", info)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the container cluster
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def info(self) -> 'outputs.VirtualClusterContainerInfo':
        return pulumi.get(self, "info")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the container provider
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class VirtualClusterEksInfo(dict):
    def __init__(__self__, *,
                 namespace: str):
        pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter
    def namespace(self) -> str:
        return pulumi.get(self, "namespace")


@pulumi.output_type
class VirtualClusterTag(dict):
    """
    An arbitrary set of tags (key-value pairs) for this virtual cluster.
    """
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        An arbitrary set of tags (key-value pairs) for this virtual cluster.
        :param str key: The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
        :param str value: The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
        """
        return pulumi.get(self, "value")


